# pyalgo_pkg

This is package is for basic algorithms in python.  

The purpose of this library is to learn the algorithms.  
this is an experiment that I do to improve my code skills and to get a better
understanding of how certain algorithms work.

if you see anything that you think that needs to be fixed
or that accidentally stolen from somewhere else so contact me, and I'll fix this.

import as ['import pyalgo']()


**Gmail:**  
gilad.dotann@gmail.com



# The new features:

***
<br />

**Algocryption:**  

I added algocryption which is a directory for encryption algorithms:  
Including 'RSA'